@@ -18,10 +18,15 @@ module God
       end
       
       def test
-        usage = `df | grep -i " #{self.mount_point}$" | awk '{print $5}' | sed 's/%//'`
-        usage.to_i > self.above
+        usage = `df -P | grep -i " #{self.mount_point}$" | awk '{print $5}' | sed 's/%//'`
+        if usage.to_i > self.above
+          self.info = "disk space out of bounds"
+          return true
+        else
+          self.info = "disk space ok"
+          return false
+        end
       end
     end
-    
   end
-end
+end
\ No newline at end of file
