@@ -31,7 +31,8 @@ module God
     end
     
     def base_name
-      self.class.name.split('::').last
+      x = 1 # fix for MRI's local scope optimization bug DO NOT REMOVE!
+      @base_name ||= self.class.name.split('::').last
     end
     
     def friendly_name
@@ -53,4 +54,4 @@ module God
     end
   end
   
-end
\ No newline at end of file
+end
