@@ -2,8 +2,17 @@ module God
   module System
   
     class Process
+      def self.fetch_system_poller
+        @@poller ||= if SlashProcPoller.usable?
+		       SlashProcPoller
+		     else
+		       PortablePoller
+		     end
+      end
+
       def initialize(pid)
         @pid = pid.to_i
+        @poller = self.class.fetch_system_poller.new(@pid)
       end
       
       # Return true if this process is running, false otherwise
@@ -13,43 +22,29 @@ module God
       
       # Memory usage in kilobytes (resident set size)
       def memory
-        ps_int('rss')
+        @poller.memory
       end
       
       # Percentage memory usage
       def percent_memory
-        ps_float('%mem')
+        @poller.percent_memory
       end
       
       # Percentage CPU usage
       def percent_cpu
-        ps_float('%cpu')
-      end
-      
-      # Seconds of CPU time (accumulated cpu time, user + system)
-      def cpu_time
-        time_string_to_seconds(ps_string('time'))
+        @poller.percent_cpu
       end
       
       private
       
-      def ps_int(keyword)
-        `ps -o #{keyword}= -p #{@pid}`.to_i
-      end
-      
-      def ps_float(keyword)
-        `ps -o #{keyword}= -p #{@pid}`.to_f
-      end
-      
-      def ps_string(keyword)
-        `ps -o #{keyword}= -p #{@pid}`.strip
-      end
-      
-      def time_string_to_seconds(text)
-        _, minutes, seconds, useconds = *text.match(/(\d+):(\d{2}).(\d{2})/)
-        (minutes.to_i * 60) + seconds.to_i
+      def fetch_system_poller
+        if SlashProcPoller.usable?
+          SlashProcPoller
+        else
+          PortablePoller
+        end
       end
     end
   
   end
-end
\ No newline at end of file
+end
